@@ -40,7 +40,8 @@ G_DECLARE_FINAL_TYPE (EphyWebView, ephy_web_view, EPHY, WEB_VIEW, WebKitWebView)
                                         "^https?://[^/\\.[:space:]]+.*$|" \
                                         "^about:.*$|" \
                                         "^data:.*$|" \
-                                        "^file:.*$" \
+                                        "^file:.*$|" \
+                                        "^inspector://.*$" \
                                         ")"
 
 #define EPHY_WEB_VIEW_DOMAIN_REGEX "^localhost(\\.[^[:space:]]+)?(:\\d+)?(:[0-9]+)?(/.*)?$|" \
